summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/ghost.cc
diff options
context:
space:
mode:
authorShmuale Mark <shm.mark@gmail.com>2014-05-14 08:55:33 -0400
committergammafunk <gammafunk@gmail.com>2014-05-26 22:44:46 -0500
commitfb02dadd07b4c6ce572780c6540cf35fa28ea716 (patch)
treee4fabe336a1ed79df01b05cf9d45ef204f1f0196 /crawl-ref/source/ghost.cc
parent3f3b3254086107b7b464f65559d0f920c52c8827 (diff)
downloadcrawl-ref-fb02dadd07b4c6ce572780c6540cf35fa28ea716.tar.gz
crawl-ref-fb02dadd07b4c6ce572780c6540cf35fa28ea716.zip
Don't make dancing weapon stats dependent on mass.
The reasoning in comments seemed to be that it rewarded investing in strength to lug around heavy weapons, but if item weight does not exist there doesn't seem to be much reason to keep that around. This also nerfs dancing weapon defenses, on the whole, but that seems fair.
Diffstat (limited to 'crawl-ref/source/ghost.cc')
-rw-r--r--crawl-ref/source/ghost.cc31
1 files changed, 13 insertions, 18 deletions
diff --git a/crawl-ref/source/ghost.cc b/crawl-ref/source/ghost.cc
index cf8879f22b..1075bea24b 100644
--- a/crawl-ref/source/ghost.cc
+++ b/crawl-ref/source/ghost.cc
@@ -667,7 +667,6 @@ void ghost_demon::ugly_thing_add_resistance(bool very_ugly,
void ghost_demon::init_dancing_weapon(const item_def& weapon, int power)
{
- int mass = item_mass(weapon);
int delay = property(weapon, PWPN_SPEED);
int damg = property(weapon, PWPN_DAMAGE);
@@ -677,34 +676,30 @@ void ghost_demon::init_dancing_weapon(const item_def& weapon, int power)
colour = weapon.colour;
fly = FL_LEVITATE;
// We want Tukima to reward characters who invest heavily in both
// carrying capacity and Hexes skill. Therefore, heavy weapons are a bit
// stronger when animated, and benefit much more from very high skill.
// First set up what the monsters will look like at very high skill.
// Daggers are weak here! In the table, "44+22" means d44+d22 with
// d22 being base damage and d44 coming from power.
-
- // Giant spiked club: speed 12, 44+22 damage, 35 AC, 70 HP, 16 EV
- // Bardiche: speed 10, 40+20 damage, 20 AC, 40 HP, 15 EV
- // Dagger: speed 20, 8+ 4 damage, 2 AC, 4 HP, 20 EV
- // Quick blade: speed 23, 10+ 5 damage, 5 AC, 10 HP, 22 EV
- // Cutlass: speed 18, 14+ 7 damage, 9 AC, 18 HP, 19 EV
+ // Giant spiked club: speed 12, 44+22 damage, 22 AC, 36 HP, 16 EV
+ // Bardiche: speed 10, 40+20 damage, 18 AC, 40 HP, 15 EV
+ // Dagger: speed 20, 8+ 4 damage, 4 AC, 20 HP, 20 EV
+ // Quick blade: speed 23, 10+ 5 damage, 5 AC, 14 HP, 22 EV
+ // Cutlass: speed 18, 14+ 7 damage, 7 AC, 24 HP, 19 EV
xl = 15;
speed = 30 - delay;
ev = 25 - delay / 2;
- ac = mass / 10;
+ ac = damg;
damage = 2 * damg;
- max_hp = mass / 5;
-
- // If you aren't an awesome spellcaster, nerf the weapons. Do it in
- // a way that lays most of the penalty on heavy weapons.
+ max_hp = delay * 2;
- speed = max(3, speed - (10 - power / 10));
- ev = max(3, ev - (10 - power / 10));
+ // Don't allow the speed to become too low.
+ speed = max(3, (speed / 2) * (1 + power / 100));
+ ev = max(3, ev * power / 100);
ac = ac * power / 100;
max_hp = max(5, max_hp * power / 100);
damage = max(1, damage * power / 100);
@@ -677,34 +676,30 @@ void ghost_demon::init_dancing_weapon(const item_def& weapon, int power)
colour = weapon.colour;
fly = FL_LEVITATE;
- // We want Tukima to reward characters who invest heavily in both
- // carrying capacity and Hexes skill. Therefore, heavy weapons are a bit
- // stronger when animated, and benefit much more from very high skill.
+ // We want Tukima to reward characters who invest heavily in
+ // Hexes skill. Therefore, weapons benefit from very high skill.
- // First set up what the monsters will look like at very high skill.
+ // First set up what the monsters will look like with 100 power.
// Daggers are weak here! In the table, "44+22" means d44+d22 with
// d22 being base damage and d44 coming from power.